@@ -65,7 +65,7 @@ int32_t SPVM__Thread__join(SPVM_ENV* env, SPVM_VALUE* stack) {
     nt_thread->join();
   }
   catch (std::exception& cpp_exception){
-    env->die_v2(env, stack, "[System Error]std::thread join failed:%s", __func__, FILE_NAME, __LINE__, cpp_exception.what());
+    env->die(env, stack, "[System Error]std::thread join failed:%s", __func__, FILE_NAME, __LINE__, cpp_exception.what());
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
